act.plotting.TimeSeriesDisplay
==============================

.. currentmodule:: act.plotting

.. autoclass:: TimeSeriesDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TimeSeriesDisplay.__init__
      ~TimeSeriesDisplay.add_colorbar
      ~TimeSeriesDisplay.add_subplots
      ~TimeSeriesDisplay.assign_to_figure_axis
      ~TimeSeriesDisplay.day_night_background
      ~TimeSeriesDisplay.fill_between
      ~TimeSeriesDisplay.plot
      ~TimeSeriesDisplay.plot_barbs_from_spd_dir
      ~TimeSeriesDisplay.plot_barbs_from_u_v
      ~TimeSeriesDisplay.plot_time_height_xsection_from_1d_data
      ~TimeSeriesDisplay.put_display_in_subplot
      ~TimeSeriesDisplay.qc_flag_block_plot
      ~TimeSeriesDisplay.set_xrng
      ~TimeSeriesDisplay.set_yrng
      ~TimeSeriesDisplay.time_height_scatter
   
   

   
   
   